@@ -46,6 +46,11 @@ class CreateProject(show.ShowOne):
             metavar='<domain>',
             help='Domain owning the project (name or ID)',
         )
+        parser.add_argument(
+            '--parent',
+            metavar='<project>',
+            help='Parent of the project (name or ID)',
+        )
         parser.add_argument(
             '--description',
             metavar='<description>',
@@ -85,6 +90,13 @@ class CreateProject(show.ShowOne):
             domain = common.find_domain(identity_client,
                                         parsed_args.domain).id
 
+        parent = None
+        if parsed_args.parent:
+            parent = utils.find_resource(
+                identity_client.projects,
+                parsed_args.parent,
+            ).id
+
         enabled = True
         if parsed_args.disable:
             enabled = False
@@ -96,6 +108,7 @@ class CreateProject(show.ShowOne):
             project = identity_client.projects.create(
                 name=parsed_args.name,
                 domain=domain,
+                parent=parent,
                 description=parsed_args.description,
                 enabled=enabled,
                 **kwargs
@@ -110,8 +123,6 @@ class CreateProject(show.ShowOne):
                 raise e
 
         project._info.pop('links')
-        # TODO(stevemar): Remove the line below when we support multitenancy
-        project._info.pop('parent_id', None)
         return zip(*sorted(six.iteritems(project._info)))
 
 
@@ -230,6 +241,11 @@ class SetProject(command.Command):
             metavar='<name>',
             help='Set project name',
         )
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='Domain owning <project> (name or ID)',
+        )
         parser.add_argument(
             '--description',
             metavar='<description>',
@@ -260,6 +276,7 @@ class SetProject(command.Command):
         identity_client = self.app.client_manager.identity
 
         if (not parsed_args.name
+                and not parsed_args.domain
                 and not parsed_args.description
                 and not parsed_args.enable
                 and not parsed_args.property
@@ -274,6 +291,8 @@ class SetProject(command.Command):
         kwargs = {}
         if parsed_args.name:
             kwargs['name'] = parsed_args.name
+        if parsed_args.domain:
+            kwargs['domain'] = parsed_args.domain
         if parsed_args.description:
             kwargs['description'] = parsed_args.description
         if parsed_args.enable:
